@@ -1,7 +1,7 @@
-__version__ = "2.4.3"
-# __version__ has to be defined in the first line
-
+from . import _version
+from ._classify_API import classify
 from .classifiers import (
+    CLASSIFIERS,
     BoxPlot,
     EqualInterval,
     FisherJenks,
@@ -10,20 +10,19 @@ from .classifiers import (
     JenksCaspall,
     JenksCaspallForced,
     JenksCaspallSampled,
-    MaxP,
+    KClassifiers,
     MaximumBreaks,
+    MaxP,
     NaturalBreaks,
-    Quantiles,
     Percentiles,
+    PrettyBreaks,
+    Quantiles,
     StdMean,
     UserDefined,
-    load_example,
     gadf,
-    KClassifiers,
-    CLASSIFIERS,
+    load_example,
 )
-
-from .pooling import Pooled
 from .greedy import greedy
+from .pooling import Pooled
 
-from ._classify_API import classify
+__version__ = _version.get_versions()["version"]
