@@ -27,6 +27,7 @@ __all__ = [
     "NaturalBreaks",
     "Quantiles",
     "Percentiles",
+    "PrettyBreaks",
     "StdMean",
     "UserDefined",
     "gadf",
@@ -48,6 +49,7 @@ CLASSIFIERS = (
     "NaturalBreaks",
     "Quantiles",
     "Percentiles",
+    "PrettyBreaks",
     "StdMean",
     "UserDefined",
 )
@@ -454,6 +456,41 @@ def bin1d(x, bins):
     return (binIds, counts)
 
 
+def _pretty_number(x, rounded=True):
+    exp = np.floor(np.log10(x))
+    f = x / 10**exp
+    if rounded:
+        if f < 1.5:
+            nf = 1.0
+        elif f < 3.0:
+            nf = 2.0
+        elif f < 7.0:
+            nf = 5.0
+        else:
+            nf = 10.0
+    else:
+        if f <= 1.0:
+            nf = 1.0
+        elif f <= 2.0:
+            nf = 2.0
+        elif f <= 5.0:
+            nf = 5.0
+        else:
+            nf = 10.0
+
+    return nf * 10.0**exp
+
+
+def _pretty(y, k=5):
+    low = y.min()
+    high = y.max()
+    rg = _pretty_number(high - low, False)
+    d = _pretty_number(rg / (k - 1), True)
+    miny = np.floor(low / d) * d
+    maxy = np.ceil(high / d) * d
+    return np.arange(miny, maxy + 0.5 * d, d)
+
+
 def load_example():
     """
     Helper function for doc tests
@@ -1147,7 +1184,6 @@ class HeadTailBreaks(MapClassifier):
         self.name = "HeadTailBreaks"
 
     def _set_bins(self):
-
         x = self.y.copy()
         bins = []
         bins = head_tail_breaks(x, bins)
@@ -1324,6 +1360,41 @@ class Percentiles(MapClassifier):
             return new
 
 
+class PrettyBreaks(MapClassifier):
+    def __init__(self, y, k=5):
+        """
+        Pretty breakpoints
+
+        Computes breaks that are equally spaced round values which
+        cover the range of values in `y`. The breaks are chosen so that
+        they are 1, 2, or 5 times a power of 10.
+
+
+        Parameters
+        ----------
+        y : array (n,1)
+            attribute to classify
+        k : int
+            The number of desired classes
+
+
+        Notes
+        -----
+        The number of classes may be different from the specified `k`,
+        as the rounding of the upper bounds takes precedent.
+
+        The lower bound of the first interval will be equal to the
+        minimum of the data.
+        """
+        self.k = k
+        MapClassifier.__init__(self, y)
+        self.name = "Pretty"
+
+    def _set_bins(self):
+        bins = _pretty(self.y, self.k)
+        self.bins = bins[1:]
+
+
 class BoxPlot(MapClassifier):
     """
     BoxPlot Map Classification.
@@ -1521,12 +1592,14 @@ class StdMean(MapClassifier):
 
     Parameters
     ----------
-
     y : numpy.array
-        :math:`(n,1)`, values to classify.
+        :math:`(n,1)`, values to classify
     multiples : numpy.array (default [-2, -1, 1, 2])
         The multiples of the standard deviation to add/subtract from
-        the sample mean to define the bins
+        the sample mean to define the bins.
+    anchor : bool (default False)
+        Anchor upper bound of one class to the sample mean.
+
 
     Attributes
     ----------
@@ -1540,6 +1613,17 @@ class StdMean(MapClassifier):
     counts : numpy.array
         :math:`(k,1)`, the number of observations falling in each class.
 
+    Notes
+    -----
+
+    If anchor is True, one of the intervals will have its closed upper bound
+    equal to the mean of y. Intermediate intervals will have widths equal to
+    the standard deviation of y. The first interval will be closed on the
+    minimum value of y, and the last interval will be closed on the maximum of
+    y. The first and last intervals may have widths different from the
+    intermediate intervals.
+
+
     Examples
     --------
 
@@ -1563,11 +1647,20 @@ class StdMean(MapClassifier):
 
     >>> list(st3.counts)
     [0, 0, 57, 0, 1]
-
+    >>> stda = mapclassify.StdMean(cal, anchor=True)
+    >>> stda.k
+    9
+    >>> stda.bins
+    array([ 125.92810345,  672.57333208, 1219.21856072, 1765.86378936,
+           2312.50901799, 2859.15424663, 3405.79947527, 3952.4447039 ,
+           4111.45      ])
+    >>> cal.mean(), cal.std(), cal.min(), cal.max()
+    (125.92810344827588, 546.6452286365233, 0.13, 4111.45)
     """
 
-    def __init__(self, y, multiples=[-2, -1, 1, 2]):
+    def __init__(self, y, multiples=[-2, -1, 1, 2], anchor=False):
         self.multiples = multiples
+        self.anchor = anchor
         MapClassifier.__init__(self, y)
         self.name = "StdMean"
 
@@ -1575,6 +1668,10 @@ class StdMean(MapClassifier):
         y = self.y
         s = y.std(ddof=1)
         m = y.mean()
+        if self.anchor:
+            min_z = int((y.min() - m) / s)
+            max_z = int((y.max() - m) / s) + 1
+            self.multiples = list(range(min_z, max_z))
         cuts = [m + s * w for w in self.multiples]
         y_max = y.max()
         if cuts[-1] < y_max:
@@ -1765,7 +1862,6 @@ class NaturalBreaks(MapClassifier):
         self.name = "NaturalBreaks"
 
     def _set_bins(self):
-
         x = self.y.copy()
         k = self.k
         values = np.array(x)
